package com.ff.game.service.impl;

import java.util.List;
import com.ff.base.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ff.game.mapper.GamePlatformMapper;
import com.ff.game.domain.GamePlatform;
import com.ff.game.service.IGamePlatformService;

/**
 * 平台管理Service业务层处理
 *
 * @author shi
 * @date 2025-02-10
 */
@Service
public class GamePlatformServiceImpl implements IGamePlatformService
{
    @Autowired
    private GamePlatformMapper gamePlatformMapper;

    /**
     * 查询平台管理
     *
     * @param id 平台管理主键
     * @return 平台管理
     */
    @Override
    public GamePlatform selectGamePlatformById(Long id)
    {
        return gamePlatformMapper.selectGamePlatformById(id);
    }

    /**
     * 查询平台管理列表
     *
     * @param gamePlatform 平台管理
     * @return 平台管理
     */
    @Override
    public List<GamePlatform> selectGamePlatformList(GamePlatform gamePlatform)
    {
        return gamePlatformMapper.selectGamePlatformList(gamePlatform);
    }

    /**
     * 新增平台管理
     *
     * @param gamePlatform 平台管理
     * @return 结果
     */
    @Override
    public int insertGamePlatform(GamePlatform gamePlatform)
    {
        gamePlatform.setCreateTime(DateUtils.getNowDate());
        return gamePlatformMapper.insertGamePlatform(gamePlatform);
    }

    /**
     * 修改平台管理
     *
     * @param gamePlatform 平台管理
     * @return 结果
     */
    @Override
    public int updateGamePlatform(GamePlatform gamePlatform)
    {
        gamePlatform.setUpdateTime(DateUtils.getNowDate());
        return gamePlatformMapper.updateGamePlatform(gamePlatform);
    }

    /**
     * 批量删除平台管理
     *
     * @param ids 需要删除的平台管理主键
     * @return 结果
     */
    @Override
    public int deleteGamePlatformByIds(Long[] ids)
    {
        return gamePlatformMapper.deleteGamePlatformByIds(ids);
    }

    /**
     * 删除平台管理信息
     *
     * @param id 平台管理主键
     * @return 结果
     */
    @Override
    public int deleteGamePlatformById(Long id)
    {
        return gamePlatformMapper.deleteGamePlatformById(id);
    }



    /**
     * 选择最大排序号
     *
     * @return {@link Integer }
     */
    @Override
    public Integer selectMaxSortNo() {
        return gamePlatformMapper.selectMaxSortNo();
    }
}
