package com.ff.game.service;

import java.util.List;
import com.ff.game.domain.GamePlatform;

/**
 * 平台管理Service接口
 * 
 * @author shi
 * @date 2025-02-10
 */
public interface IGamePlatformService 
{
    /**
     * 查询平台管理
     * 
     * @param id 平台管理主键
     * @return 平台管理
     */
     GamePlatform selectGamePlatformById(Long id);

    /**
     * 查询平台管理列表
     * 
     * @param gamePlatform 平台管理
     * @return 平台管理集合
     */
     List<GamePlatform> selectGamePlatformList(GamePlatform gamePlatform);

    /**
     * 新增平台管理
     * 
     * @param gamePlatform 平台管理
     * @return 结果
     */
     int insertGamePlatform(GamePlatform gamePlatform);

    /**
     * 修改平台管理
     * 
     * @param gamePlatform 平台管理
     * @return 结果
     */
     int updateGamePlatform(GamePlatform gamePlatform);

    /**
     * 批量删除平台管理
     * 
     * @param ids 需要删除的平台管理主键集合
     * @return 结果
     */
     int deleteGamePlatformByIds(Long[] ids);

    /**
     * 删除平台管理信息
     * 
     * @param id 平台管理主键
     * @return 结果
     */
     int deleteGamePlatformById(Long id);


    /**
     * 选择最大排序号
     *
     * @return {@link Integer }
     */
    Integer selectMaxSortNo();


}
